"use strict";(function(v,i){typeof exports=="object"?module.exports=i():v.MonacoBootstrapWindow=i()})(this,function(){const v=D(),i=$(),f=i.process;async function h(n,d,o){const p=setTimeout(()=>{console.error("[resolve window config] Could not resolve window configuration within 10 seconds, but will continue to wait...")},1e4);performance.mark("code/willWaitForWindowConfig");const s=await i.context.resolveConfiguration();performance.mark("code/didWaitForWindowConfig"),clearTimeout(p),typeof o?.canModifyDOM=="function"&&o.canModifyDOM(s);const{forceEnableDeveloperKeybindings:b,disallowReloadKeybinding:a,removeDeveloperKeybindingsAfterLoad:t}=typeof o?.configureDeveloperSettings=="function"?o.configureDeveloperSettings(s):{forceEnableDeveloperKeybindings:!1,disallowReloadKeybinding:!1,removeDeveloperKeybindingsAfterLoad:!1},c=!!f.env.VSCODE_DEV,x=c||b;let w;x&&(w=j(a));const u=globalThis.MonacoBootstrap.setupNLS();let l=u.availableLanguages["*"]||"en";l==="zh-tw"?l="zh-Hant":l==="zh-cn"&&(l="zh-Hans"),window.document.documentElement.setAttribute("lang",l),window.MonacoEnvironment={};const m={baseUrl:`${v.fileUriFromPath(s.appRoot,{isWindows:f.platform==="win32",scheme:"vscode-file",fallbackAuthority:"vscode-app"})}/out`,"vs/nls":u,preferScriptTags:!0};m.trustedTypesPolicy=window.trustedTypes?.createPolicy("amdLoader",{createScriptURL(r){if(r.startsWith(window.location.origin))return r;throw new Error(`Invalid script url: ${r}`)}});const e=c?"../node_modules":"../node_modules.asar";m.paths={"vscode-textmate":`${e}/vscode-textmate/release/main.js`,"vscode-oniguruma":`${e}/vscode-oniguruma/release/main.js`,vsda:`${e}/vsda/index.js`,"@xterm/xterm":`${e}/@xterm/xterm/lib/xterm.js`,"@xterm/addon-canvas":`${e}/@xterm/addon-canvas/lib/addon-canvas.js`,"@xterm/addon-image":`${e}/@xterm/addon-image/lib/addon-image.js`,"@xterm/addon-search":`${e}/@xterm/addon-search/lib/addon-search.js`,"@xterm/addon-serialize":`${e}/@xterm/addon-serialize/lib/addon-serialize.js`,"@xterm/addon-unicode11":`${e}/@xterm/addon-unicode11/lib/addon-unicode11.js`,"@xterm/addon-webgl":`${e}/@xterm/addon-webgl/lib/addon-webgl.js`,"@vscode/iconv-lite-umd":`${e}/@vscode/iconv-lite-umd/lib/iconv-lite-umd.js`,jschardet:`${e}/jschardet/dist/jschardet.min.js`,"@vscode/vscode-languagedetection":`${e}/@vscode/vscode-languagedetection/dist/lib/index.js`,"vscode-regexp-languagedetection":`${e}/vscode-regexp-languagedetection/dist/index.js`,"tas-client-umd":`${e}/tas-client-umd/lib/tas-client-umd.js`},typeof o?.beforeLoaderConfig=="function"&&o.beforeLoaderConfig(m),require.config(m),u.pseudo&&require(["vs/nls"],function(r){r.setPseudoTranslation(u.pseudo)}),typeof o?.beforeRequire=="function"&&o.beforeRequire(s),require(n,async r=>{try{const g=d(r,s);g instanceof Promise&&(await g,w&&t&&w())}catch(g){y(g,x)}},y)}function j(n){const d=i.ipcRenderer,o=function(t){return[t.ctrlKey?"ctrl-":"",t.metaKey?"meta-":"",t.altKey?"alt-":"",t.shiftKey?"shift-":"",t.keyCode].join("")},p=f.platform==="darwin"?"meta-alt-73":"ctrl-shift-73",s="123",b=f.platform==="darwin"?"meta-82":"ctrl-82";let a=function(t){const c=o(t);c===p||c===s?d.send("vscode:toggleDevTools"):c===b&&!n&&d.send("vscode:reloadWindow")};return window.addEventListener("keydown",a),function(){a&&(window.removeEventListener("keydown",a),a=void 0)}}function y(n,d){d&&i.ipcRenderer.send("vscode:openDevTools"),console.error(`[uncaught exception]: ${n}`),n&&typeof n!="string"&&n.stack&&console.error(n.stack)}function D(){return window.MonacoBootstrap}function $(){return window.vscode}return{load:h}});

//# sourceMappingURL=https://ticino.blob.core.windows.net/sourcemaps/019f4d1419fbc8219a181fab7892ebccf7ee29a2/core/bootstrap-window.js.map
