"use strict";
/**
 * Copyright (c) 2020, Microsoft Corporation (MIT License).
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getWorkerPipeName = void 0;
function getWorkerPipeName(conoutPipeName) {
    return conoutPipeName + "-worker";
}
exports.getWorkerPipeName = getWorkerPipeName;//# sourceMappingURL=https://ticino.blob.core.windows.net/sourcemaps/019f4d1419fbc8219a181fab7892ebccf7ee29a2/node_modules/node-pty/lib/shared/conout.js.map