/*!--------------------------------------------------------
 * Copyright (C) Microsoft Corporation. All rights reserved.
 *--------------------------------------------------------*/define("vs/code/electron-sandbox/issue/issueReporterMain.nls",{"vs/base/browser/ui/button/button":["More Actions..."],"vs/base/browser/ui/iconLabel/iconLabelHover":["Loading..."],"vs/base/common/actions":["(empty)"],"vs/base/common/platform":["_"],"vs/code/electron-sandbox/issue/issueReporterPage":["Include my system information","Include my currently running processes","Include my workspace metadata","Include my enabled extensions","Include A/B experiment info","Include additional extension info",'Before you report an issue here please <a href="https://github.com/microsoft/vscode/wiki/Submitting-Bugs-and-Suggestions" target="_blank">review the guidance we provide</a>.',"Please complete the form in English.","This is a","File on","An issue source is required.","Try to reproduce the problem after {0}. If the problem only reproduces when extensions are active, it is likely an issue with an extension.","disabling all extensions and reloading the window","Extension","The issue reporter is unable to create issues for this extension. Please visit {0} to report an issue.","The issue reporter is unable to create issues for this extension, as it does not specify a URL for reporting issues. Please check the marketplace page of this extension to see if other instructions are available.","Title","Please enter a title.","A title is required.","The title is too long.","Please enter details.","A description is required.","show","Extension does not have additional data to include.","show","show","show","show","show"],"vs/code/electron-sandbox/issue/issueReporterService":["hide","show","Create on GitHub","Preview on GitHub","Loading data...","GitHub query limit exceeded. Please wait.","Similar issues","Open","Closed","Open","Closed","No similar issues found","Bug Report","Feature Request","Performance Issue","Select source","Visual Studio Code","An extension","Extensions marketplace","Don't know","This extension handles issues outside of VS Code","The '{0}' extension prefers to use an external issue reporter. To be taken to that issue reporting experience, click the button below.","Open External Issue Reporter","Steps to Reproduce","Share the steps needed to reliably reproduce the problem. Please include actual and expected results. We support GitHub-flavored Markdown. You will be able to edit your issue and add screenshots when we preview it on GitHub.","Steps to Reproduce","When did this performance issue happen? Does it occur on startup or after a specific series of actions? We support GitHub-flavored Markdown. You will be able to edit your issue and add screenshots when we preview it on GitHub.","Description","Please describe the feature you would like to see. We support GitHub-flavored Markdown. You will be able to edit your issue and add screenshots when we preview it on GitHub.","We have written the needed data into your clipboard because it was too large to send. Please paste.","Select extension","Extensions are disabled","No current experiments."],"vs/platform/theme/common/iconRegistry":["The id of the font to use. If not set, the font that is defined first is used.","The font character associated with the icon definition.","Icon for the close action in widgets.","Icon for goto previous editor location.","Icon for goto next editor location."]});

//# sourceMappingURL=https://ticino.blob.core.windows.net/sourcemaps/019f4d1419fbc8219a181fab7892ebccf7ee29a2/core/vs/code/electron-sandbox/issue/issueReporterMain.nls.js.map
